@@ -1,5 +1,5 @@
 package Sys::Info::Base;
-$Sys::Info::Base::VERSION = '0.7807';
+$Sys::Info::Base::VERSION = '0.7808';
 use strict;
 use warnings;
 
@@ -142,11 +142,11 @@ Sys::Info::Base
 
 =head1 VERSION
 
-version 0.7807
+version 0.7808
 
 =head1 SYNOPSIS
 
-    use base qw(Sys::Info::Base);
+    use parent qw(Sys::Info::Base);
     #...
     sub foo {
         my $self = shift;
@@ -202,7 +202,7 @@ L<Sys::Info>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
