@@ -1,10 +1,10 @@
 package Sys::Info::Constants;
-$Sys::Info::Constants::VERSION = '0.7807';
+$Sys::Info::Constants::VERSION = '0.7808';
 use strict;
 use warnings;
 
 use Carp qw( croak );
-use base qw( Exporter );
+use parent qw( Exporter );
 
 BEGIN {
     if ( ! defined &OSID ) {
@@ -101,7 +101,7 @@ Sys::Info::Constants
 
 =head1 VERSION
 
-version 0.7807
+version 0.7808
 
 =head1 SYNOPSIS
 
@@ -155,7 +155,7 @@ L<Sys::Info>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
